.. Djiffy documentation master file, created by
   sphinx-quickstart on Tue Jun 13 11:20:47 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Djiffy Documentation
====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   codedocs
   Change Log <changelog>


.. include:: ../README.rst
    :start-after: sphinx-start-marker-do-not-remove


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
